@@ -1,20 +1,29 @@
 # test line added
 # test demo team
+#from configparser import ConfigParser
+#from importlib import resources  # Python 3.7+
+import sys
 from flask import Flask, render_template, request
-from dataLoad.data_loader import DataGetter
-from dataPreprocessing.preProcess import Preprocessor
-from dataVisualization.visualization import DataVisualization
-from modelTraining.classificationModels import ClassificationModelTuner
-from prediction.predict import Prediction
+#from data_loader import DataGetter
+#from preProcess import Preprocessor
+#from visualization import DataVisualization
+#from classificationModels import ClassificationModelTuner
+#from predict import Prediction
+
+from pneuro import data_loader
+from pneuro import preProcess
+from pneuro import visualization
+from pneuro import classificationModels
+from pneuro import predict
 
 app = Flask(__name__)
 
 # All class instantiation
-data_getter = DataGetter()
-preprocessor = Preprocessor()
-visuals = DataVisualization()
-classification_model = ClassificationModelTuner()
-prediction = Prediction()
+data_getter = data_loader.DataGetter()
+preprocessor = preProcess.Preprocessor()
+visuals = visualization.DataVisualization()
+classification_model = classificationModels.ClassificationModelTuner()
+prediction = predict.Prediction()
 
 @app.route('/', methods=['GET'])
 def index():
